@@ -20,11 +20,11 @@ test_that("Mu computes the correct block sums", {
   set.seed(1045)
   X <- matrix(rnorm(36), ncol = 6)
   
-  expect_equal(Mu(X, l = c(2, 2)), c(0.6946552, -0.1936238, -0.4166834, 
-                                    -0.4640347, -0.1491637, -0.112317, 
-                                     0.08525641, -0.4745453, -0.5687769), 
+  expect_equal(Mu(X, l = c(2, 2)), c(0.6946552, -0.4640347, 0.08525641,
+                                     -0.1936238, -0.1491637, -0.4745453,
+                                     -0.4166834, -0.112317, -0.5687769), 
                tolerance = 1e-7)
-  expect_equal(Mu(X, l = c(3, 3)), c(-0.04461205, -0.327058, -0.4336385, 0.09453829), 
+  expect_equal(Mu(X, l = c(3, 3)), c(-0.04461205, -0.4336385, -0.327058, 0.09453829), 
                tolerance = 1e-7)
   
   # errors:
